@@ -360,8 +360,8 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 		    sql = "SELECT `cn` from jos_xgroups WHERE cn='" + group + "'"
 
 		groupsFromDB = {}
-		for group in db.query(sql, None):
-			groupsFromDB[group.cn] = 1
+		for dgroup in db.query(sql, None):
+			groupsFromDB[dgroup.cn] = 1
 
 		l = ldap.initialize(ldapServer)
 		l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -382,7 +382,7 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 			cn = str(entry['cn'][0])
 			if cn not in groupsFromDB:
 				if verbose:
-					print "deleting ldap group '" + cn + "'"
+					print "deleting group '" + cn + "' from ldap"
 				hubzero.utilities.group.delete_ldap_group(cn)	
 	
 
@@ -392,9 +392,9 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 	else:
 	    sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups WHERE cn='" + group + "'"
 
-	for group in db.query(sql, None):
+	for dgroup in db.query(sql, None):
 	
-		if not group.description: group.description = ""
+		if not dgroup.description: dgroup.description = ""
  
 		# get the groups membership if asked
 		groupMembers = []
@@ -405,17 +405,17 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 		    JOIN jos_xprofiles p on (p.uidNumber = m.uidNumber) 
 		    JOIN jos_xgroups g on (g.gidNumber = m.gidNumber)
 		    WHERE g.cn = %s"""
-			data = (group.cn)
+			data = (dgroup.cn)
 			
 			for userGroupMembership in db.query(sql, data):
 				groupMembers.append(str(userGroupMembership.uidNumber))
 
 		try:
-			print "syncing ldap group '" + group.cn + "'"
-			add_ldap_group(group.cn, group.description, group.gidNumber, groupMembers)
+			print "syncing group '" + dgroup.cn + "' to ldap"
+			add_ldap_group(gdroup.cn, dgroup.description, dgroup.gidNumber, dgroupMembers)
 		except ldap.ALREADY_EXISTS:
-			delete_ldap_group(group.cn)
-			add_ldap_group(group.cn, group.description, group.gidNumber, groupMembers)
+			delete_ldap_group(dgroup.cn)
+			add_ldap_group(dgroup.cn, dgroup.description, dgroup.gidNumber, groupMembers)
 
 		if groupMembers and debug:
 			print "  adding members:" + str(groupMembers)
