@@ -757,7 +757,7 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 			
 			if uid not in usersFromDB:
 				if verbose:
-					print "deleting ldap user '" + uid + "'"
+					print "deleting user '" + uid + "' from ldap"
 				try:
 					hubzero.utilities.user.delete_ldap_user(uid)
 				except ldap.NO_SUCH_OBJECT:
@@ -772,6 +772,6 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 	
 	for duser in db.query(sql, None):
 		if verbose:
-			print "syncing ldap user '" + duser.username + "'"
+			print "syncing user '" + duser.username + "' to ldap"
 		_syncuser(duser.username, hubname, syncattributes)
 	
\ No newline at end of file
